@@ -1,6 +1,6 @@
 "gstat" <-
 function (g, id, formula, locations, data = NULL, model = NULL, 
-    beta, nmax = Inf, dummy = FALSE, set, fill.all = FALSE,
+    beta, nmax = Inf, maxdist = Inf, dummy = FALSE, set, fill.all = FALSE,
 	variance = "identity") 
 {
 	if (fill.all) {
@@ -56,7 +56,7 @@ function (g, id, formula, locations, data = NULL, model = NULL,
         id = paste("var", length(g$data) + 1, sep = "")
     g$data[[id]] = list(formula = formula, locations = locations, 
         data = data, has.intercept = attr(terms(formula), "intercept"),
-		beta = beta, nmax = nmax, dummy = dummy,
+		beta = beta, nmax = nmax, maxdist = maxdist, dummy = dummy,
 		vfn = vfn)
     g$model[[id]] = model
     if (!missing(set)) {
